
This PR has the objective of <describe here>

## Changes

1. Added new `xyz` to...
2. Fixed a bug in...
3. Changed the behaviour of...
4. Improved the docs about...

## Checklist

Use this checklist for assuring the quality of pull requests that include new code and or make changes to existing code.

* [ ] Source Code rules apply:
  * [ ] Includes unit tests
  * [ ] New functions have docstrings with examples that can be run with doctest
  * [ ] New functions are included in API docs
  * [ ] Docstrings include notes for any changes to API or behaviour
  * [ ] All changes are documented in docs/changes.rst
* [ ] Versioning and history tracking rules apply:
  * [ ] Using atomic commits when possible
  * [ ] Commits are reversible when possible
  * [ ] There is no incomplete changes in the pull request
  * [ ] There is no accidental garbage added in source code
* [ ] Testing rules apply:
  * [ ] Tested locally using `tox` / `pytest`
  * [ ] Automated testing passes (see [CI](https://github.com/petl-developers/petl/actions))
  * [ ] Unit test coverage has not decreased (see [Coveralls](https://coveralls.io/github/petl-developers/petl))
* [ ] State of these changes is:
  * [ ] Just a proof of concept
  * [ ] Work in progress / Further changes needed
  * [ ] Ready to review
  * [ ] Ready to merge
